@@ -276,7 +276,11 @@ This function makes various special characters safe by escaping them."
 
 (defun rtf-map-chars (string)
   "Map some characters in an RTF string."
-  (replace-in-string (replace-in-string (rtf-safe string) "\t" "\\tab" t)
+;; RAS:  07/11/03
+;; adding support for form feed
+  (replace-in-string (replace-in-string (replace-in-string (rtf-safe string) 
+                                                           "" "\\page " t) 
+                                        "\t" "\\tab" t)
 		     "\n" "\\par\n" t)) 
 
 (defun rtf-map-colour (emacs-colour)
